@@ -1,8 +1,5 @@
-from .db import bili_database
 from .exception import BiliConnectionError, BiliDatebaseError
-import httpx
 import asyncio
-import json
 from typing import Tuple, List
 import sys
 import traceback
@@ -11,11 +8,9 @@ from nonebot.log import logger
 from nonebot.adapters.onebot.v11 import MessageSegment
 from .basicFunc import *
 from .bili_client import bili_client
+from .bili_task import bili_task_manager
 
 __PLUGIN_NAME = "[bilibilibot~视频]"
-BASEURL = 'https://api.bilibili.com/x/space/arc/search?mid={}&ps=30&tid=0&pn=1&keyword=&order=pubdate&jsonp=jsonp'
-USERINFOURL = 'https://api.bilibili.com/x/space/acc/info?mid={}&jsonp=jsonp'
-
 
 # 视频
 async def check_up_update() -> None:
@@ -28,32 +23,34 @@ async def check_up_update() -> None:
     @Returns  :
     -------
     """
-    up_list = bili_database.query_all(0)
     schedBot = nonebot.get_bot()
     #assert status == True, "数据库发生错误"
-    param_list = [[up_info[0], up_info[2]] for up_info in up_list]
+    check_up_list = bili_task_manager.get_up_check_update_list()
     results = await asyncio.gather(
-        *[bili_client.get_latest_video(uid, latest_timestamp) for uid, latest_timestamp in param_list],
+        *[bili_client.get_latest_video(uid, latest_timestamp) for uid, latest_timestamp in check_up_list],
         return_exceptions=True
     )
     
-    for i in range(len(up_list)):
+    for i in range(len(check_up_list)):
         if isinstance(results[i], tuple):
             if results[i][0] is True:
-                logger.info(f'{__PLUGIN_NAME}检测到up主<{up_list[i][1]}>更新了视频')
-                textMsg = f"【B站动态】\n <{up_list[i][1]}> 更新了视频\n标题: {results[i][2]}\n链接: https://www.bilibili.com/video/{results[i][1]}"
-                bili_database.update_info(0, results[i][3], up_list[i][0])
+                up_uid = check_up_list[i][0]
+                up_name = bili_task_manager.up_list[up_uid]["up_name"]
 
-                user_list = bili_database.query_user_relation(0, up_list[i][0])
-                for user_id in user_list:
-                    await schedBot.send_msg(message=textMsg + MessageSegment.image(results[i][4]), user_id=user_id[0])
+                logger.info(f'{__PLUGIN_NAME}检测到up主<{up_name}>更新了视频')
+                textMsg = f"【B站动态】\n <{up_name}> 更新了视频\n标题: {results[i][2]}\n链接: https://www.bilibili.com/video/{results[i][1]}"
                 
-                group_list = bili_database.query_group_relation(0, up_list[i][0])
+                bili_task_manager.update_up_info(up_uid, results[i][3])
+
+                user_list = bili_task_manager.up_list[up_uid]["user_follower"]
+                for user_id in user_list:
+                    await schedBot.send_msg(message=textMsg + MessageSegment.image(results[i][4]), user_id=user_id)
+                
+                group_list = bili_task_manager.up_list[up_uid]["group_follower"]
                 for group_id in group_list:
-                    await schedBot.send_msg(message=textMsg + MessageSegment.image(results[i][4]), group_id=group_id[0])
-            
+                    await schedBot.send_msg(message=textMsg + MessageSegment.image(results[i][4]), group_id=group_id)
         elif isinstance(results[i], (BiliAPIRetCodeError, BiliStatusCodeError, BiliConnectionError)):
-            exception_msg = f'[错误报告]\n检测up主 <{up_list[i][1]}> 更新情况时发生错误\n错误类型: {type(results[i])}\n错误信息: {results[i]}'
+            exception_msg = f'[错误报告]\n检测up主 <{up_name}> 更新情况时发生错误\n错误类型: {type(results[i])}\n错误信息: {results[i]}'
             logger.error(f"[{__PLUGIN_NAME}]" + exception_msg)
 
 async def follow_up(uid: str, user_id: str, user_type: int) -> Tuple[bool, str]:
@@ -76,31 +73,37 @@ async def follow_up(uid: str, user_id: str, user_type: int) -> Tuple[bool, str]:
     uid = str(int(uid))
     
     try:
-        result = bili_database.query_info(2, uid)
         
         # up信息不存在于数据库,对数据库进行更新
-        if not result:
+        if uid not in bili_task_manager.up_list:
             up_name, latest_timestamp = await bili_client.init_up_info(uid)
-
+            
             if up_name:
-                bili_database.insert_info(2, uid, up_name, latest_timestamp)
-                bili_database.insert_relation(0 + user_type, uid, user_id)
+                bili_task_manager.add_up_info(uid, up_name, latest_timestamp)
+                if user_type == 0:
+                    bili_task_manager.add_user_follower(0, uid, user_id)
+                else:
+                    bili_task_manager.add_group_follower(0, uid, user_id)
+               
                 logger.info(f"{__PLUGIN_NAME}用户/群 <{user_id}> 关注主播 <{up_name}> 成功")
                 return (True, up_name + f"(uid: {uid})")
             else:
                 logger.info(f'{__PLUGIN_NAME}up({uid})不存在，请检查uid')
                 return (False, uid + "(uid错误)")
+        up_name = bili_task_manager.up_list[uid]["up_name"]
         # 处理已关注
-        result1 = bili_database.query_specified_realtion(0 + user_type, user_id, uid)
-        
-        if result1:
-            logger.info(f"{__PLUGIN_NAME}用户/群 <{user_id}> 已经关注了up <{result[1]}>")
-            return (False, result[1] + "(已关注)")
-    
+        if user_type == 0 and user_id in bili_task_manager.up_list[uid]["user_follower"] or \
+            user_type == 1 and user_id in bili_task_manager.up_list[uid]["group_follower"]:
+            logger.info(f"{__PLUGIN_NAME}用户/群 <{user_id}> 已经关注了up <{up_name}>")
+            return (False, up_name + "(已关注)")
+
         # 进行关注
-        bili_database.insert_relation(0 + user_type, uid, user_id)
-        logger.info(f"{__PLUGIN_NAME}用户/群 <{user_id}> 关注up <{result[1]}> 成功")
-        return (True, result[1] + f"(uid: {uid})")
+        if user_type == 0:
+            bili_task_manager.add_user_follower(0, uid, user_id)
+        elif user_type == 1:
+            bili_task_manager.add_group_follower(0, uid, user_id)
+        logger.info(f"{__PLUGIN_NAME}用户/群 <{user_id}> 关注up <{up_name}> 成功")
+        return (True, up_name + f"(uid: {uid})")
     except BiliAPI404Error:
         return (False, uid + "(uid错误)")
     except (BiliConnectionError, BiliAPIRetCodeError, BiliStatusCodeError):
@@ -137,16 +140,22 @@ async def unfollow_up(uid: str, user_id: str, user_type: int) -> Tuple[bool, str
         return (False, uid + "(错误参数)")
     try:
     # 处理未关注
-        result = bili_database.query_specified_realtion(0 + user_type, user_id, uid)
-        if not result:
+        logger.debug(f"{uid}的关注列表{bili_task_manager.up_list[uid]['user_follower']}")
+        if uid not in bili_task_manager.up_list or \
+            user_type == 0 and user_id not in bili_task_manager.up_list[uid]["user_follower"] or \
+            user_type == 1 and user_id not in bili_task_manager.up_list[uid]["group_follower"]:
             logger.info(f'{__PLUGIN_NAME}用户/群 <{user_id}> 未关注up <{uid}>')
             return (False, uid + "(未关注)")
         
         # 进行取关
-        bili_database.delete_relation(0 + user_type, user_id, uid)
+        up_name = bili_task_manager.up_list[uid]["up_name"]
+        if user_type == 0:
+            bili_task_manager.remove_user_follower(0, uid, user_id)
+        else:
+            bili_task_manager.remove_group_follower(0, uid, user_id)
         logger.info(f'{__PLUGIN_NAME}用户/群 <{user_id}> 取关up <{uid}> 成功')
 
-        return (True, bili_database.query_info(2, uid)[1]  + f"(uid: {uid})") 
+        return (True, up_name  + f"(uid: {uid})") 
     except BiliDatebaseError:
         ex_type, ex_val, _ = sys.exc_info()
         exception_msg = f'【错误报告】\n取关up主 <{uid}> 时数据库发生错误\n错误类型: {ex_type}\n错误值: {ex_val}\n'
@@ -199,7 +208,7 @@ async def unfollow_up_list(
     failList = []
 
     for uid in uid_list:
-        isSuccess, s = await unfollow_up(uid, user_id, user_type)
+        isSuccess, s = await unfollow_up(uid, str(user_id), user_type)
         if isSuccess:
             successList.append(s)
         else:
